#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hakyll
version:              4.16.4.0
visibility:           public
id:                   hakyll-4.16.4.0-J0XC5ZM4dWfHp5dwJ66iIz
key:                  hakyll-4.16.4.0-J0XC5ZM4dWfHp5dwJ66iIz
license:              BSD-3-Clause
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt <m@jaspervdj.be>
homepage:             http://jaspervdj.be/hakyll
synopsis:             A static website compiler library
description:
    Hakyll is a static website compiler library. It provides you with the tools to
    create a simple or advanced static website using a Haskell DSL and formats
    such as markdown or RST. You can find more information, including a tutorial,
    on the website:

    * <http://jaspervdj.be/hakyll>

    If you seek assistance, there'\''s:

    * A google group: <http://groups.google.com/group/hakyll>

    * An IRC channel, @#hakyll@ on irc.libera.chat (we *do not* have a channel on Freenode anymore)

    Additionally, there'\''s the Haddock documentation in the different modules,
    meant as a reference.

category:             Web
abi:                  8af818ae77694243009b966d45c8c7a3
exposed:              True
exposed-modules:
    Hakyll Hakyll.Commands Hakyll.Core.Compiler
    Hakyll.Core.Compiler.Internal Hakyll.Core.Configuration
    Hakyll.Core.Dependencies Hakyll.Core.File Hakyll.Core.Identifier
    Hakyll.Core.Identifier.Pattern Hakyll.Core.Item Hakyll.Core.Logger
    Hakyll.Core.Metadata Hakyll.Core.Provider
    Hakyll.Core.Provider.Metadata Hakyll.Core.Routes Hakyll.Core.Rules
    Hakyll.Core.Rules.Internal Hakyll.Core.Runtime Hakyll.Core.Store
    Hakyll.Core.UnixFilter Hakyll.Core.Util.File
    Hakyll.Core.Util.String Hakyll.Core.Writable Hakyll.Main
    Hakyll.Web.CompressCss Hakyll.Web.Feed Hakyll.Web.Html
    Hakyll.Web.Html.RelativizeUrls Hakyll.Web.Meta.JSONLD
    Hakyll.Web.Meta.OpenGraph Hakyll.Web.Meta.TwitterCard
    Hakyll.Web.Paginate Hakyll.Web.Pandoc Hakyll.Web.Pandoc.Biblio
    Hakyll.Web.Pandoc.FileType Hakyll.Web.Redirect Hakyll.Web.Tags
    Hakyll.Web.Template Hakyll.Web.Template.Context
    Hakyll.Web.Template.Internal Hakyll.Web.Template.Internal.Element
    Hakyll.Web.Template.Internal.Trim Hakyll.Web.Template.List

hidden-modules:
    Data.List.Extended Data.Yaml.Extended Hakyll.Check
    Hakyll.Core.Compiler.Require
    Hakyll.Core.Identifier.Pattern.Internal Hakyll.Core.Item.SomeItem
    Hakyll.Core.Provider.Internal Hakyll.Core.Provider.MetadataCache
    Hakyll.Core.Util.Parser Paths_hakyll Hakyll.Preview.Poll
    Hakyll.Preview.Server Hakyll.Web.Pandoc.Binary

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hakyll-4.16.4.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hakyll-4.16.4.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hakyll-4.16.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hakyll
hs-libraries:         HShakyll-4.16.4.0-J0XC5ZM4dWfHp5dwJ66iIz
depends:
    aeson-2.2.2.0-Bvq1RZLTB982HJyF7e96XU base-4.18.2.1 binary-0.8.9.1
    blaze-html-0.9.2.0-403xIyraa8W9X2ANuW0FPg bytestring-0.11.5.3
    containers-0.6.7 data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    deepseq-1.4.8.1 directory-1.3.8.5
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    fsnotify-0.4.4.0-6bPTrqD3dyFCbpeBwRBUHS
    hashable-1.4.7.0-LB47rq9amzm4H74gyqVlYy
    http-conduit-2.3.9.1-JuSKcL2x7gvHrvi4XVCcUw
    http-types-0.12.4-BfnwqLIFvgHNb88uBZwW9
    lrucache-1.2.0.1-34e4rU2OpGtGXjnvLtyFkI mtl-2.3.1
    network-uri-2.6.4.2-DXIr6FO81fkKKSx83uC4Cz
    optparse-applicative-0.18.1.0-7oEyKoVs7Vv7h3tuBTvFI7
    pandoc-3.6-IqEeweEQsHMFXHSUCIu4GX parsec-3.1.16.1 process-1.6.19.0
    random-1.2.1.3-5FoUrrA3875KkJXWnCWBBA
    regex-tdfa-1.3.2.5-DSpNPpF3mjD6KIMmBJHiEZ
    resourcet-1.2.6-5o8OKNGoLEyGu1zh0QIf5q
    scientific-0.3.8.1-25vWQKW70jDDFFn5H243Ra
    tagsoup-0.14.8-7VOpHkFP4Dh5DvT1rQTUnd template-haskell-2.20.0.0
    text-2.0.2 time-1.12.2
    time-locale-compat-0.1.1.5-8XUEctZKps57K6Zw5siYoh
    vector-0.13.2.0-9FXioZw2Nye8eueJzIuHK4
    wai-3.2.4-56REQg4dhfjHKYLZyIkMb9
    wai-app-static-3.1.9-FjlimYwfdIo5jIUltdUUMA
    warp-3.4.0-2XxsbnRRw9KIGpeg46CAEy
    yaml-0.11.11.2-FLCCKo0n0nJK5o0PhDW0y0

haddock-interfaces:   /usr/share/doc/haskell-hakyll/html/hakyll.haddock
haddock-html:         /usr/share/doc/haskell-hakyll/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

